#
# spec file for package libopenshot-audio
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 9

Name:           libopenshot-audio
Version:        0.3.2
Release:        1.4
Summary:        Audio library for the OpenShot video editor
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Other
URL:            https://openshot.org/
Source0:        %{name}-%{version}.tar.xz
Source99:       %{name}.changes

BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)

%description
The OpenShot Audio Library allows editing and playback of audio.
It was derived from the JUCE library.

%package -n     %{name}%{sover}
Summary:        Audio library for the OpenShot video editor
Group:          System/Libraries

%description -n %{name}%{sover}
The OpenShot Audio Library allows editing and playback of audio.
It was derived from the JUCE library.

This package contains the shared library.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}

%description    devel
The OpenShot Audio Library.

This package contains header files and libraries needed to develop
application that use %{name}.

%prep
%autosetup -p1

%build
export SOURCE_DATE_EPOCH=$(date +%s -r %{S:99})
%cmake \
	-DCMAKE_SHARED_LINKER_FLAGS="-Wl,--as-needed" \
	%{nil}
%cmake_build

%install
%cmake_install

%post   -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%doc AUTHORS
%license COPYING
%{_libdir}/%{name}.so.*

%files devel
%{_bindir}/openshot*
%{_libdir}/%{name}.so
%{_includedir}/%{name}
%{_mandir}/man?/openshot*
%dir %{_libdir}/cmake/OpenShotAudio
%{_libdir}/cmake/OpenShotAudio/FindASIO.cmake
%{_libdir}/cmake/OpenShotAudio/OpenShotAudio*.cmake

%changelog
* Thu Dec 28 2023 dmueller@suse.com
- Update to version 0.3.2:
  * Bumping version to 0.3.2 (SO remains 9 - not changed)
  * Updating github CI builders to no longer use Ubuntu 18.04, and add 22.04
* Tue Apr 11 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.3.1:
  * Bumping version to 0.3.1, SO remains version 9 (since no API changes are included)
  * Updated license info
  * Updated README
* Tue Dec  6 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.3.0:
  * Part of the OpenShot Video Editor v3.0.0 Release
  * Improved documentation
* Mon Nov  1 2021 code@bnavigator.de
- Update to version 0.2.2:
  * Bump version to 0.2.2 (SO still 8)
  * Ensure NEED_ASIO is always set
* Mon Aug 30 2021 tiwai@suse.com
- Use the released version 0.2.1 instead of development branch;
  updated _service as well
* Fri Aug 27 2021 ecsos@opensuse.org
- Update to version 0.2.1+5:
  * Updated version to 0.2.1 SO 8
  * Ensure NEED_ASIO is always set
  * Bump actions/upload-artifact from 2.2.3 to 2.2.4 (#128)
  * Add juce_dsp module
  * CMake: Correct EXPORTED config install path (#127)
  * Rename version_info files to NAME.env (#126)
  * Name generate-docs workflow file sensibly
  * Rename docs temp dir
  * Generate and install JuceHeader.h
  * Bump actions/upload-artifact from v2.2.2 to v2.2.3
  * GH Actions: Build and publish docs (#122)
  * CMake: Don't export openshot-audio-demo (#121)
  * Ensure we use C++11 to build demo code (#120)
  * Gitlab-ci: Update Windows builder configs (#119)
  * CMake: Create and install EXPORTED configuration (#118)
  * Normalize repo to LF (Unix) line endings, enforce (#117)
  * Add repo name to workflow job title
  * README: Add Github Actions status badge
  * Update copyright in README (#113)
  * README: Remove Travis build shield
  * Revert version back to 0.2.0
  * Test bumping the version (for gitlab-ci deployment testing)
  * Test bumping the version (for gitlab-ci deployment testing)
  * Fixing regex syntax to extract version
  * Fixing regex syntax to extract version
  * Fixing regex syntax to extract version
  * Fixing regex syntax to extract version
  * Attempting to extract VERSION and SO from CMakeLists.txt file, to be used in build system (and deployment system)
  * Adding CI_PIPELINE_ID into the version info
  * Updating git log format to be consistent across all 3 repos (for final release publishing reasons)
  * Experimental multi-thread builds for Linux and Mac
  * CI: Pare down Windows deps (#110)
  * Add Dependabot checking for Actions (#109)
  * CI: Switch to Github Actions (#108)
  * Formatting fixes for INSTALL docs (#104)
  * Fix stale yml message to be a literal string
  * Travis: Add Focal build (#102)
  * Updating stale github comment message
  * Upgrade JUCE to 5.4.7 (#88)
  * Ensure full 40-character hashes in changelog
  * Testing -stdlib=libc++ to prevent linking with libstd++ from gcc
  * Updating tag on gitlab to use new Ubuntu bionic build server
  * Make JUCE source path configurable
  * Revert "Fix isfinite() for ruby bindings"
  * Add shell script to output version (#95)
  * Travis: Add macOS build w/ newer XCode (#94)
  * Update formatting for commit logs
* Thu Mar 12 2020 hpj@urpla.net
- Update to version 0.2.0+5:
  * Updating auto-stale conditions (90 days warning, 10 days to respond, only issues, ignore assigned issues)
  * Adding stale bot for github issue management
  * Adding -dev2 to version (merging master back to develop)
  * Release branch for 0.2.0 (SO 7)
  * CMake: Add hex-version helper source (#89)
  * Travis: Remove homebrew (too slow) (#87)
  * Accidental version revert
  * Fix broken hex logic
  * Updating HEX version for 0.2.0: 0x200
* Sun Aug 18 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to current master (devel) branch, fixes build for Factory.
- Run spec-cleaner, use modern macros.
* Fri May  3 2019 Adrian Schröter <adrian@suse.de>
- update to version 0.1.8
  * just internal code organisation changes
* Mon Sep 24 2018 Adrian Schröter <adrian@suse.de>
- update to version 0.1.7
  * version update only
* Mon Jul  2 2018 adrian@suse.de
- update to version 0.1.6
  * soname change only
* Tue Mar  6 2018 adrian@suse.de
- update to version 0.1.5
  * soname change only
* Fri Jan 13 2017 jengelh@inai.de
- Update descriptions
* Thu Jan 12 2017 adrian@suse.de
- adapt for openSUSE Factory
* Thu Oct 20 2016 avvissu@yandex.by
- Initial package
